.. :changelog:

History
-------

1.1.1 (2016-04-12)
++++++++++++++++++

* Fixed problem building connections cache key
* Updated documentation

1.1.0 (2016-04-05)
++++++++++++++++++

* Added ``urls`` attribute to ``MappingType`` to be able to custom urls of Elasticsearch servers
* Added ``GenericElasticsearchManager`` class to make queries without specific ``MappingType`` class


1.0.1 (2016-03-31)
++++++++++++++++++

* Fixed problem running --update-settings


1.0.0 (2016-03-24)
++++++++++++++++++

* New settings var for configure Elasticsearch connection.
* Better project structure for distribution.


1.0.0rc1 (2016-02-29)
+++++++++++++++++++++

* First release on PyPI.
